%define myname botan
%define major 1
%define libname %mklibname %{myname} %{major}
%define develname %mklibname %{myname} -d
%define staticname %mklibname %{myname} -s -d

Name:           %{myname}
Version:        1.10.12
%define subrel	1
Release:        %mkrel 1
Summary:        Crypto library written in C++
Group:          System/Libraries
License:        BSD
URL:            http://botan.randombit.net/
# tarfile is stripped using repack.sh. original tarfile to be found
# here: http://botan.randombit.net/releases/Botan-%%{version}.tgz
Source0:        Botan-%{version}.stripped.tgz
Source1:        README.fedora
Patch0:		botan-1.10.12-CVE-2015-7827-CVE-2016-2849.patch
BuildRequires:  gcc-c++
BuildRequires:  python
BuildRequires:  bzip2-devel
BuildRequires:  zlib-devel
BuildRequires:  gmp-devel
BuildRequires:  openssl-devel

%description
Botan is a BSD-licensed crypto library written in C++. It provides a
wide variety of basic cryptographic algorithms, X.509 certificates and
CRLs, PKCS \#10 certificate requests, a filter/pipe message processing
system, and a wide variety of other features, all written in portable
C++. The API reference, tutorial, and examples may help impart the
flavor of the library.

%package -n     %{libname}
Summary:        Main library for %{myname}
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
Obsoletes:      %{mklibname botan 1.10}

%description -n %{libname}
Botan is a BSD-licensed crypto library written in C++. It provides a
wide variety of basic cryptographic algorithms, X.509 certificates and
CRLs, PKCS \#10 certificate requests, a filter/pipe message processing
system, and a wide variety of other features, all written in portable
C++. The API reference, tutorial, and examples may help impart the
flavor of the library.

%package -n     %{develname}
Summary:        Development files for %{name}
Group:          Development/Other
Requires:       %{libname} = %{version}
Requires:       pkgconfig
Requires:       bzip2-devel
Requires:       zlib-devel
Requires:       gmp-devel
Requires:       openssl-devel
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n     %{staticname}
Summary:        Static libraries for %{name}
Group:          Development/Other
Requires:       %{name}-devel = %{version}-%{release}

%description -n %{staticname}
The %{staticname} package contains the static libraries
of %{name}.

%prep
%setup -q -n Botan-%{version}
%patch0 -p1
cp -av %{SOURCE1} .

%build
# we have the necessary prerequisites, so enable optional modules
%define enable_modules gnump,bzip2,zlib,openssl

# fixme: maybe disable unix_procs, very slow.
%define disable_modules %{nil}

./configure.py \
        --prefix=%{_prefix} \
        --libdir=%{_lib} \
        --cc=gcc \
        --os=linux \
        --cpu=%{_arch} \
        --enable-modules=%{enable_modules} \
        --disable-modules=%{disable_modules}

# (ab)using CXX as an easy way to inject our CXXFLAGS
make CXX="g++ ${CXXFLAGS:-%{optflags}}" %{?_smp_mflags}


%install
make install \
     DESTDIR=%{buildroot}%{_prefix} \
     DOCDIR=_doc \
     INSTALL_CMD_EXEC="install -p -m 755" \
     INSTALL_CMD_DATA="install -p -m 644" \

%check
make CXX="g++ ${CXXFLAGS:-%{optflags}}" %{?_smp_mflags} check

# these checks would fail
mv checks/validate.dat{,.orig}
awk '/\[.*\]/{f=0} /\[(RC5.*|RC6|IDEA)\]/{f=1} (f && !/^#/){sub(/^/,"#")} {print}' \
    checks/validate.dat.orig > checks/validate.dat
LD_LIBRARY_PATH=%{buildroot}%{_libdir} ./check --validate

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/libbotan*-*.so.%{major}*
%doc _doc/readme.txt doc/log.txt doc/credits.txt
%doc doc/license.txt doc/pgpkey.txt
%doc README.fedora

%files -n %{develname}
%doc doc/examples
%{_bindir}/botan-config-1.10
%{_includedir}/*
%{_libdir}/libbotan-1.10.so
%{_libdir}/pkgconfig/botan-1.10.pc
%exclude %{_libdir}/libbotan-1.10.a

%files -n %{staticname}
%attr(0644,root,root) %{_libdir}/lib*.a


%changelog
* Wed May 18 2016 luigiwalser <luigiwalser> 1.10.12-1.1.mga5
+ Revision: 1016810
- add patch from debian to fix CVE-2015-7827 and CVE-2016-2849

  + oden <oden>
    - no subrel for new versions, note to self
    - 1.10.12 (fixes CVE-2015-572[67], CVE-2015-7827, CVE-2016-219[45] (#17737))

* Wed Oct 15 2014 umeabot <umeabot> 1.10.8-4.mga5
+ Revision: 746315
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1.10.8-3.mga5
+ Revision: 693514
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.10.8-2.mga5
+ Revision: 678207
- Mageia 5 Mass Rebuild

* Sun May 04 2014 shlomif <shlomif> 1.10.8-1.mga5
+ Revision: 620001
- New version 1.10.8

* Fri Oct 18 2013 luigiwalser <luigiwalser> 1.8.13-4.mga4
+ Revision: 503487
- fix typo in make check section

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

  + dams <dams>
    - clean specfile

* Fri Jan 11 2013 umeabot <umeabot> 1.8.13-3.mga3
+ Revision: 347147
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + shlomif <shlomif>
    - imported package botan

